# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Hash-StoredIterator
Version:	0.008
Release:	23.%{__distinit}%{__distvers}
Summary:	Functions for accessing a hash's internal iterator
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Hash-StoredIterator
Source0:	https://cpan.metacpan.org/modules/by-module/Hash/Hash-StoredIterator-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter >= 4:5.10.0
BuildRequires:	perl(ExtUtils::CBuilder)
BuildRequires:	perl(ExtUtils::ParseXS) >= 3.15
BuildRequires:	perl(Module::Build) >= 0.42
# Module Runtime
BuildRequires:	perl(B)
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(Test2::Bundle::Extended)
BuildRequires:	perl(Test2::Tools::Spec)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Avoid provides for private shared objects
%{?perl_default_filter}

%description
In perl all hashes have an internal iterator. This iterator is used by the
each() function, as well as by keys() and values(). Because these all share use
of the same iterator, they tend to interact badly with each other when nested.

Hash::StoredIterator gives you access to get, set, and init the iterator inside
a hash. This allows you to store the current iterator, use each / keys / values
etc., and then restore the iterator, which helps you to ensure you do not
interact badly with other users of the iterator.

Along with low-level get / set / init functions, there are also 2 variations of
each() that let you act upon each key/value pair in a safer way than vanilla
each().

This module can also export new implementations of keys() and values() that
stash and restore the iterator so that they are safe to use within each().

%prep
%setup -q -n Hash-StoredIterator-%{version}

%build
perl Build.PL --installdirs=vendor --optimize="%{optflags}"
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
./Build test

%files
%license LICENSE
%doc Changes README
%{perl_vendorarch}/auto/Hash/
%{perl_vendorarch}/Hash/
%{_mandir}/man3/Hash::StoredIterator.3*

%changelog
* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 0.008-23
- Perl 5.38 rebuild

* Sun Apr 23 2023 Paul Howarth <paul@city-fan.org> - 0.008-22
- Use SPDX-format license tag

* Thu Jun  2 2022 Paul Howarth <paul@city-fan.org> - 0.008-20
- Perl 5.36 rebuild

* Mon May 24 2021 Paul Howarth <paul@city-fan.org> - 0.008-17
- Perl 5.34 rebuild

* Mon Jun 29 2020 Paul Howarth <paul@city-fan.org> - 0.008-14
- Perl 5.32 rebuild

* Thu Nov  7 2019 Paul Howarth <paul@city-fan.org> - 0.008-12
- Bump some versioned dependencies as per META.*

* Fri Jun  7 2019 Paul Howarth <paul@city-fan.org> - 0.008-10
- Perl 5.30 rebuild

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 0.008-7
- Perl 5.28 rebuild

* Mon Aug  7 2017 Paul Howarth <paul@city-fan.org> - 0.008-5
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Wed Jun 14 2017 Paul Howarth <paul@city-fan.org> - 0.008-3
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Thu Aug 11 2016 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - Silenced eich deprecation warnings in tests
  - Typo fixes (GH#3)
  - Added a license file
  - Testing using Travis and AppVeyor
  - No longer depending on Fennec: using Test2 instead, reducing the dependency
    chain
  - Added repository metadata (GH#4)
- This release by MSCHWERN → update source URL

* Wed May 18 2016 Paul Howarth <paul@city-fan.org> - 0.007-9
- Classify buildreqs by usage
- Simplify find command using -empty and -delete

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 0.007-5
- Perl 5.20 rebuild

* Thu Aug 15 2013 Paul Howarth <paul@city-fan.org> - 0.007-1
- Initial RPM version
